"""
    EMIL BillingService

    The EMIL BillingService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import eis.billing
from eis.billing.model.invoice_item_class import InvoiceItemClass
from eis.billing.model.invoice_payments_class import InvoicePaymentsClass
globals()['InvoiceItemClass'] = InvoiceItemClass
globals()['InvoicePaymentsClass'] = InvoicePaymentsClass
from eis.billing.model.omit_type_class import OmitTypeClass


class TestOmitTypeClass(unittest.TestCase):
    """OmitTypeClass unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testOmitTypeClass(self):
        """Test OmitTypeClass"""
        # FIXME: construct object with mandatory attributes with example values
        # model = OmitTypeClass()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
