"""
    EMIL BillingService

    The EMIL BillingService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.billing
from eis.billing.api.policy_billing_api import PolicyBillingApi  # noqa: E501


class TestPolicyBillingApi(unittest.TestCase):
    """PolicyBillingApi unit test stubs"""

    def setUp(self):
        self.api = PolicyBillingApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_policy_billing(self):
        """Test case for create_policy_billing

        Create the Policy Billing  # noqa: E501
        """
        pass

    def test_list_policies_billings(self):
        """Test case for list_policies_billings

        List policies billings  # noqa: E501
        """
        pass

    def test_update_policy_billing(self):
        """Test case for update_policy_billing

        Update the request message  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
